@@ -130,6 +130,22 @@ class VariableOsInstallProxy(NetHelper, Variable):
     value = ""
 
 
+class VariableOsInstallNetType(NetHelper, ReadonlyVariable):
+    """
+    Тип сетевого устройства: сейчас eth или wlan
+    """
+    type = "list"
+    
+    def _getType(self, iface):
+        if ip.isWireless(iface):
+            return "wlan"
+        return "eth"
+
+    def get(self):
+        interfaces = self.Get('os_install_net_interfaces')
+        return [self._getType(x) for x in interfaces]
+
+
 class VariableOsInstallNetInterfaces(NetHelper, ReadonlyVariable):
     """
     Net interface devices
